FoxyProxy options

Proxy mode:

# Proxies

### Import your proxies from FoxyProxy on Mozilla Firefox or from another computer.

# Global Settings

Sync settings with Google | Send anonymous usage information to FoxyProxy
Animate FoxyProxy Icon | Open "Release Notes" tab when FoxyProxy is updated.

# Import / Export

## Import FoxyProxy settings from a file

### This tool allows you to import your proxies from FoxyProxy on Mozilla Firefox or from another computer.

## Export FoxyProxy settings to a file

### A file named FoxyProxy-export.fpx will be saved in your default Chrome Downloads directory. You can use it to import your settings into another instance of Google Chrome or FoxyProxy on Firefox.

# Logging

Enabled | Maximum size before log wraps

# QuickAdd

### QuickAdd adds a dynamic URL pattern to a proxy when you press a keyboard shortcut.

Keyboard shortcuts are now configured via the Chrome extensions keyboard shortcut dialog.
Configure Keyboard Shortcuts

You can also add a pattern by clicking "Quick Add" from the FoxyProxy extension icon, or through the context menu (by right-clicking in a page.)

Enabled

Temporary
Pattern proxy |
Pattern Name |
URL pattern template |
Example for |

Whitelist | URLs matching this pattern are loaded through this proxy
Blacklist | URLs matching this pattern are NOT loaded through this proxy

Wildcards | Example: *mail.yahoo.com/*
Regular expression | Example: ^https?://.*\mail\.yahoo\.com/.*$

#

Created By | Eric H. Jung
Contributions By | Loic Duros
| Jesper Staun Hansen
| Georg Koppen
| Michael G. Collins
Copyright 2006-2014 FoxyProxy, Inc. All Rights Reserved. Released under the GPL license. Home Support Forums Credits

Do not show this warning again.

This file may overwrite your existing proxies. You can add these proxies to the existing list or replace your existing list.

- General
- Proxy Details
- URL Patterns

Enabled
Proxy Name |
Proxy Notes |
Color |

Direct internet connection (no proxy)

Manual Proxy Configuration
Help! Where are settings for HTTP, SSL, FTP, Gopher, and SOCKS?
Host or IP Address Port
SOCKS proxy? SOCKS v4/4a SOCKS v5
Save Login Credentials Authentication Username Password Password - again |

Automatic proxy configuration URL
Reload PAC every minutes
Notify me about proxy auto-configuration file loads
Notify me about proxy auto-configuration file errors

Here you can specify when this proxy is and is not used.

Enabled Temporary
Pattern Name |
Current URL |
URL pattern |

Whitelist | URLs matching this pattern are loaded through this proxy
Blacklist | URLs matching this pattern are NOT loaded through this proxy

Wildcards | Example: *mail.yahoo.com/*
Regular expression | Example: https?://.*\mail\.yahoo\.com/.*

Set as the new host:port of which proxy configuration?

Enabled | Color | Proxy Name | Proxy Notes

Temporary
Pattern proxy |
Pattern Name |
URL pattern template |

Whitelist | URLs matching this pattern are loaded through this proxy
Blacklist | URLs matching this pattern are NOT loaded through this proxy

Wildcards | Example: *mail.yahoo.com/*
Regular expression | Example: https?://.*\mail\.yahoo\.com/.*